@@ -2,7 +2,10 @@ from mmanalyser import config
 import re
 import numpy as np
 from pydub import AudioSegment
+from pypinyin import pinyin as get_pinyin, Style
 from mmanalyser.utils.nlu_tools import NluTools
+from mmanalyser.utils.wer import wer
+from mmanalyser.utils.number_to_chinese import number_to_chinese
 import logging
 
 
@@ -14,12 +17,14 @@ class ExpressionAnalyser:
     '''
     表达能力分析器
 
-    asr数据格式：{"pause_detection": [[3280, 3922], [7781, 8688]], "text_corrected":  [], "text":  [[[0, 1170], "领导你好，"],[[8940, 12250], "我在嘉兴，"], [[12250, 13490], "有两家造纸厂，"]]}
+    asr数据格式：{"pause_detection": [[3280, 3922], [7781, 8688]], "text_corrected":  [], "text":  [[[0, 1170], "领导你好，"],
+                                     [[8940, 12250], "我在嘉兴，"], [[12250, 13490], "有两家造纸厂，"]]}
     '''
-    def __init__(self, rationality_service_url=None, timeout=10):
+    def __init__(self, rationality_service_url=None):
         self.logger = logging.getLogger(self.__class__.__name__)
         self.rationality_service_url = rationality_service_url
-        self.nlu = NluTools(timeout=timeout)
+        self.nlu = NluTools()
+        self.ntc = number_to_chinese()
 
     def get_expression_score(self, asr, audio_path=None):
         """
@@ -37,10 +42,8 @@ class ExpressionAnalyser:
             'expression_score': float,  //表达能力分数
             }
         """
-        raw_text, recognition_duration, pause_moment =\
-                self.__get_text_information_from_asr(asr)
-        text, text_length, particle_count, repeat_one_count, ranhou_count =\
-                self.__disfluency_detection(raw_text)
+        raw_text, recognition_duration, pause_moment = self.__get_text_information_from_asr(asr)
+        text, text_length, particle_count, repeat_one_count, ranhou_count = self.__disfluency_detection(raw_text)
         mandarin_score = self.__parse_mandarin_score(text)
         talk_speed = self.__get_talk_speed(text_length, recognition_duration)
         audio_clear = self.__is_audio_clear(audio_path, text_length, recognition_duration, mandarin_score)
@@ -70,16 +73,30 @@ class ExpressionAnalyser:
         talk_speed = self.__get_talk_speed(text_length, recognition_duration)
         return talk_speed
 
-    def get_mandarin_score(self, asr):
+    def get_mandarin_score(self, asr, pinyin=None):
         '''
         获取普通话标准程度
 
         Args:
             asr: asr结果
-
+            pinyin: 拼音识别结果（"wo2 ai2 ni3"）
         Returns:
             float: 普通话标准程度
         '''
+        def func(x):
+            if x > 1.5:
+                return  0.15/x
+            elif x < 0.5:
+                return 0.05*(0.5-x)/0.5 + 0.95
+            else:
+                return (1.5-x)/1.5*0.8+0.15
+
+        if pinyin:
+            text = self.ntc.parse(''.join([x[1] for x in asr['text']]))
+            text = re.sub("！|，|？|。| |,", '', text)
+            text = ' '.join([x[0] for x in get_pinyin(str(text), style=Style.TONE3)])
+            return func(wer(text, pinyin)) * 100
+
         raw_text, recognition_duration, pause_moment = \
             self.__get_text_information_from_asr(asr)
         text, text_length, particle_count, repeat_one_count, ranhou_count = \
@@ -306,7 +323,9 @@ if __name__ == '__main__':
         "text_corrected":  [[[0, 1170], "领导你好，"], [[1170, 2370], "我叫秦嘉涵，"], [[2370, 5530], "今年26岁，"], [[5530, 8040], "是浙江龙游人，"], [[8040, 8940], "我，"], [[8940, 12250], "我在龙游，"], [[12250, 13490], "有两家造纸厂，"], [[13490, 19330], "有4年的维修工禁令。"]],
         "text":  [[[0, 1170], "领导你好，"], [[1170, 2370], "我叫秦嘉涵，"], [[2370, 5530], "今年26岁，"], [[5530, 8040], "是浙江龙游人，"], [[8040, 8940], "我，"], [[8940, 12250], "我在龙游，"], [[12250, 13490], "有两家造纸厂，"], [[13490, 19330], "有4年的维修工禁令。"]]
     }
-    print(ea.get_expression_score(asr=fake_asr, verbose=True))
+    fake_pinyin = ' '.join([x[0] for x in get_pinyin("领导你好", style=Style.TONE3)])
+    # print(ea.get_expression_score(asr=fake_asr, verbose=True))
+    print(ea.get_mandarin_score(asr=fake_asr, pinyin=fake_pinyin))
 
 
 
