@@ -4,14 +4,13 @@ import requests
 
 
 class NluTools(object):
-    def __init__(self, timeout=10):
+    def __init__(self):
         self.logger = logging.getLogger(self.__class__.__name__)
-        self.timeout = timeout
 
     def httpcall(self, url, req):
         try:
             response = requests.post(
-                    url, json.dumps(req).encode("utf8"), timeout=self.timeout)
+                    url, json.dumps(req).encode("utf8"), timeout=10)
         except Exception as e:
             self.logger.exception("nlu error[%s]", e)
             return None
